==> sddm_0.17.0.orig.tar.gz: sddm-0.17.0/data/translations/ko.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ko">
<context>
    <name>PictureBox</name>
    <message>
        <source>Press to login</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>%1 (Wayland)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>TextConstants</name>
    <message>
        <source>Warning, Caps Lock is ON!</source>
        <translation>경고: Caps Lock이 켜져 있습니다!</translation>
    </message>
    <message>
        <source>Layout</source>
        <translation>레이아웃</translation>
    </message>
    <message>
        <source>Login</source>
        <translation>로그인</translation>
    </message>
    <message>
        <source>Login failed</source>
        <translation>로그인 실패</translation>
    </message>
    <message>
        <source>Login succeeded</source>
        <translation>로그인 성공</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>암호</translation>
    </message>
    <message>
        <source>Enter your username and password</source>
        <translation>사용자 이름과 암호를 입력하십시오</translation>
    </message>
    <message>
        <source>Select your user and enter password</source>
        <translation>사용자를 선택하고 암호를 입력하십시오</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>다시 시작</translation>
    </message>
    <message>
        <source>Session</source>
        <translation>세션</translation>
    </message>
    <message>
        <source>Shutdown</source>
        <translation>컴퓨터 끄기</translation>
    </message>
    <message>
        <source>User name</source>
        <translation>사용자 이름</translation>
    </message>
    <message>
        <source>Welcome to %1</source>
        <translation>%1에 오신 것을 환영합니다</translation>
    </message>
</context>
</TS>

==> sddm_0.18.1.orig.tar.gz: sddm-0.18.1/data/translations/ko.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ko">
<context>
    <name>PictureBox</name>
    <message>
        <source>Press to login</source>
        <translation>로그인하려면 누르십시오</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>%1 (Wayland)</source>
        <translation>%1(Wayland)</translation>
    </message>
</context>
<context>
    <name>TextConstants</name>
    <message>
        <source>Warning, Caps Lock is ON!</source>
        <translation>경고: Caps Lock이 켜져 있습니다!</translation>
    </message>
    <message>
        <source>Layout</source>
        <translation>레이아웃</translation>
    </message>
    <message>
        <source>Login</source>
        <translation>로그인</translation>
    </message>
    <message>
        <source>Login failed</source>
        <translation>로그인 실패</translation>
    </message>
    <message>
        <source>Login succeeded</source>
        <translation>로그인 성공</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>암호</translation>
    </message>
    <message>
        <source>Enter your username and password</source>
        <translation>사용자 이름과 암호를 입력하십시오</translation>
    </message>
    <message>
        <source>Select your user and enter password</source>
        <translation>사용자를 선택하고 암호를 입력하십시오</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>다시 시작</translation>
    </message>
    <message>
        <source>Session</source>
        <translation>세션</translation>
    </message>
    <message>
        <source>Shutdown</source>
        <translation>컴퓨터 끄기</translation>
    </message>
    <message>
        <source>User name</source>
        <translation>사용자 이름</translation>
    </message>
    <message>
        <source>Welcome to %1</source>
        <translation>%1에 오신 것을 환영합니다</translation>
    </message>
</context>
</TS>
